@@ -159,7 +159,7 @@ class ApiRpcClient(object):
             stream_proto.listener = task.on_stdin
 
             try:
-                yield client.call(task, *args)
+                yield client.call(task, *args, size=stream_proto.term.get_size())
 
                 res = yield task.wait_result()
                 yield client.shutdown()
@@ -193,14 +193,16 @@ class ApiRpcClient(object):
     @cli('Push appliction volume application', arguments=(
         arg('source', help='Push source'),
         arg('destination', help='Push destination'),
+        arg('--remove', help='Allow to remove files', default=False, action='store_true'),
+        arg('--force', help='Don\'t ask confirmation', default=False, action='store_true'),
     ))
     @inlineCallbacks
-    def sync(self, source, destination, **kwargs):
+    def sync(self, source, destination, remove, force, **kwargs):
 
         src = get_storage(source)
         dst = get_storage(destination)
 
-        yield storage_sync(src, dst, confirm=True, verbose=True)
+        yield storage_sync(src, dst, confirm=not force, verbose=True, remove=remove)
 
     @cli('List running tasks')
     @inlineCallbacks
@@ -283,7 +285,7 @@ class ApiRpcClient(object):
         def on_result(data):
             print 'result: %s' % pprintpp.pformat(data)
 
-        self._remote_exec('init', name, os.path.realpath(path))
+        return self._remote_exec('init', name, os.path.realpath(path))
 
 
     def print_app_details(self, app):
@@ -306,11 +308,11 @@ class ApiRpcClient(object):
 
             if app['status'] != 'error':
                 if 'web_service' in app and app['web_service'] == service['name']:
-                    web.append(app['fullname'])
+                    web.append('http://' + app['fullname'])
 
                     if 'public_urls' in app and app['public_urls']:
                         for url in app['public_urls']:
-                            web.append(url)
+                            web.append('http://' + url)
 
             x.add_row([
                 service['name'],
@@ -517,19 +519,22 @@ class ApiRpcClient(object):
     ))
     @inlineCallbacks
     def set(self, name, val, **kwargs):
-        data = yield self._remote_exec('set_var', self.on_vars_result, name, val)
+        data = yield self._remote_exec('set_var', name, val)
+        self.on_vars_result(data)
 
     @cli('Unset variable value', arguments=(
         arg('name', help='Variable name'),
     ))
     @inlineCallbacks
     def unset(self, name, **kwargs):
-        data = yield self._remote_exec('rm_var', self.on_vars_result, name)
+        data = yield self._remote_exec('rm_var', name)
+        self.on_vars_result(data)
 
     @cli('List variables')
     @inlineCallbacks
     def vars(self, **kwargs):
-        data = yield self._remote_exec('list_vars', self.on_vars_result)
+        data = yield self._remote_exec('list_vars')
+        self.on_vars_result(data)
 
     @cli('Unpublish an application', arguments=(
         arg('domain', help='Domain to publish'),
