@@ -227,8 +227,9 @@ class FileIOProtocol(basic.LineReceiver):
     @inlineCallbacks
     def do_mkdir(self, data):
         path = yield self.resolve_file_path(**data['args']['ref'])
-        file_path = os.path.join(path, data['args']['path'])
-        os.makedirs(file_path)
+        file_path = os.path.join(path, data['args']['path']).decode('utf-8')
+        if not os.path.exists(file_path):
+            os.makedirs(file_path)
         self.transport.write(json.dumps(True) + '\r\n')
         self.transport.loseConnection()
 
@@ -736,7 +737,7 @@ def diff_has_changes(volume_diff):
     return volume_diff['new'] or volume_diff['upd'] or volume_diff['del']
 
 @inlineCallbacks
-def storage_sync(src, dst, confirm=False, verbose=False):
+def storage_sync(src, dst, confirm=False, verbose=False, remove=False):
 
     start = time()
 
@@ -755,6 +756,9 @@ def storage_sync(src, dst, confirm=False, verbose=False):
 
     volume_diff = compare(snapshot_src, snapshot_dst, drift=(time() - start))
 
+    if not remove:
+        volume_diff['del'] = []
+
     if not diff_has_changes(volume_diff):
         print('Files are in sync already.')
         return
